@@ -112,7 +112,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Encode;
 use Moo;
@@ -121,7 +121,8 @@ use Novel::Robot::Browser;
 use Novel::Robot::Parser::Jjwxc;
 use Novel::Robot::Parser::Dddbbb;
 
-has browser => ( is => 'rw', 
+has browser => (
+    is      => 'rw',
     default => sub {
         my ($self) = @_;
         my $browser = new Novel::Robot::Browser();
@@ -130,37 +131,39 @@ has browser => ( is => 'rw',
 );
 
 has site => (
-    is => 'rw', 
-    default => sub { '' }, 
+    is      => 'rw',
+    default => sub {''},
 );
 
 has parser => (
-    is => 'rw', 
-    lazy => 1, 
-    default => \&set_site, 
+    is      => 'rw',
+    lazy    => 1,
+    default => \&set_site,
 );
 
 sub set_site {
-        my ($self, $site) = @_;
-        $self->{site} = $site if($site);
-        $self->{parser_list}{$self->{site}} //= eval qq[new Novel::Robot::Parser::$self->{site}()];
-        $self->{parser}  = $self->{parser_list}{$self->{site}};
-}
+    my ( $self, $site ) = @_;
+    $self->{site} = $site if ($site);
+    $self->{parser_list}{ $self->{site} } //= eval qq[new Novel::Robot::Parser::$self->{site}()];
+    $self->{parser} = $self->{parser_list}{ $self->{site} };
+} ## end sub set_site
 
 sub set_site_by_url {
-        my ($self, $url) = @_;
+    my ( $self, $url ) = @_;
 
-        my $site = ($url=~m#^http://www\.jjwxc\.net/#) ? 'Jjwxc'  :
-        ($url=~m#^http://www\.dddbbb\.net/#) ? 'Dddbbb' : ''; 
+    my $site =
+          ( $url =~ m#^http://www\.jjwxc\.net/# )  ? 'Jjwxc'
+        : ( $url =~ m#^http://www\.dddbbb\.net/# ) ? 'Dddbbb'
+        :                                            '';
 
-        $self->set_site($site) if(! $self->{site} or $self->{site} ne $site);
-}
+    $self->set_site($site) if ( !$self->{site} or $self->{site} ne $site );
+} ## end sub set_site_by_url
 
 sub get_index_ref {
 
     my ( $self, @args ) = @_;
-    
-    $self->set_site_by_url($args[0]) if($args[0]=~m#^http://#);
+
+    $self->set_site_by_url( $args[0] ) if ( $args[0] =~ m#^http://# );
 
     my ($index_url) = $self->{parser}->generate_index_url(@args);
 
@@ -187,7 +190,7 @@ sub get_index_ref {
 sub get_chapter_ref {
     my ( $self, @args ) = @_;
 
-    $self->set_site_by_url($args[0]) if($args[0]=~m#^http://#);
+    $self->set_site_by_url( $args[0] ) if ( $args[0] =~ m#^http://# );
 
     my ( $chap_url, $chap_id ) = $self->{parser}->generate_chapter_url(@args);
     my $html_ref = $self->{browser}->get_url_ref($chap_url);
@@ -217,11 +220,10 @@ sub get_empty_chapter_ref {
     return \%data;
 } ## end sub get_empty_chapter_ref
 
-
 sub get_writer_ref {
     my ( $self, @args ) = @_;
 
-    $self->set_site_by_url($args[0]) if($args[0]=~m#^http://#);
+    $self->set_site_by_url( $args[0] ) if ( $args[0] =~ m#^http://# );
     my ($writer_url) = $self->{parser}->generate_writer_url(@args);
 
     my $html_ref = $self->{browser}->get_url_ref($writer_url);
